@@ -1,5 +1,4 @@
 /* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
-/* vim: set ts=8 sts=2 et sw=2 tw=80: */
 /* This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
@@ -1884,19 +1883,7 @@ nsWindowWatcher::CalculateChromeFlagsForParent(mozIDOMWindowProxy* aParent,
   chromeFlags |= WinHasOption(aFeatures, "non-private", 0, &presenceFlag) ?
     nsIWebBrowserChrome::CHROME_NON_PRIVATE_WINDOW : 0;
 
-  // Determine whether the window should have remote tabs.
-  bool remote = BrowserTabsRemoteAutostart();
-
-  if (remote) {
-    remote = !WinHasOption(aFeatures, "non-remote", 0, &presenceFlag);
-  } else {
-    remote = WinHasOption(aFeatures, "remote", 0, &presenceFlag);
-  }
-
-  if (remote) {
-    chromeFlags |= nsIWebBrowserChrome::CHROME_REMOTE_WINDOW;
-  }
-
+  // Check if it's a popup window
   chromeFlags |= WinHasOption(aFeatures, "popup", 0, &presenceFlag) ?
     nsIWebBrowserChrome::CHROME_WINDOW_POPUP : 0;
 
